======================
Django Tagging PlateIQ
======================

|travis-develop| |coverage-develop|

This is a generic tagging application for Django projects with added support for CharField IDs. Tailored for PlateIQ.

https://django-tagging.readthedocs.io/

Note that this application version requires Python 3.5 or later, and Django
1.11 or later. You can obtain Python from http://www.python.org/ and
Django from http://www.djangoproject.com/.

.. |travis-develop| image:: https://travis-ci.org/Fantomas42/django-tagging.png?branch=develop
   :alt: Build Status - develop branch
   :target: http://travis-ci.org/Fantomas42/django-tagging
.. |coverage-develop| image:: https://coveralls.io/repos/Fantomas42/django-tagging/badge.png?branch=develop
   :alt: Coverage of the code
   :target: https://coveralls.io/r/Fantomas42/django-tagging
